@@ -11,7 +11,7 @@ pins_show_progress <- function(size = 0) {
   if (is.character(size)) size <- as.integer(size)
 
   large_file <- getOption("pins.progress.size", 10^7)
-  identical(getOption("pins.progress", size > large_file), TRUE)
+  identical(getOption("pins.progress", size > large_file), TRUE) && interactive()
 }
 
 pins_save_csv <- function(x, name) {
